==> eam-wshub-proxyclient-11.4-10-sources.jar: net/datastream/schemas/mp_fields/GRIDTABLE_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour GRIDTABLE_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="GRIDTABLE_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDTABLENAME"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDTABLEALIAS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GRIDTABLE_Type", propOrder = {
    "gridtablename",
    "gridtablealias"
})
public class GRIDTABLE_Type {

    @XmlElement(name = "GRIDTABLENAME", required = true)
    protected String gridtablename;
    @XmlElement(name = "GRIDTABLEALIAS")
    protected String gridtablealias;

    /**
     * Obtient la valeur de la propriété gridtablename.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRIDTABLENAME() {
        return gridtablename;
    }

    /**
     * Définit la valeur de la propriété gridtablename.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRIDTABLENAME(String value) {
        this.gridtablename = value;
    }

    /**
     * Obtient la valeur de la propriété gridtablealias.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRIDTABLEALIAS() {
        return gridtablealias;
    }

    /**
     * Définit la valeur de la propriété gridtablealias.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRIDTABLEALIAS(String value) {
        this.gridtablealias = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/GRIDTABLE_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for GRIDTABLE_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="GRIDTABLE_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDTABLENAME"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDTABLEALIAS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GRIDTABLE_Type", propOrder = {
    "gridtablename",
    "gridtablealias"
})
public class GRIDTABLE_Type {

    @XmlElement(name = "GRIDTABLENAME", required = true)
    protected String gridtablename;
    @XmlElement(name = "GRIDTABLEALIAS")
    protected String gridtablealias;

    /**
     * Gets the value of the gridtablename property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRIDTABLENAME() {
        return gridtablename;
    }

    /**
     * Sets the value of the gridtablename property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRIDTABLENAME(String value) {
        this.gridtablename = value;
    }

    /**
     * Gets the value of the gridtablealias property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRIDTABLEALIAS() {
        return gridtablealias;
    }

    /**
     * Sets the value of the gridtablealias property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRIDTABLEALIAS(String value) {
        this.gridtablealias = value;
    }

}
